from __future__ import annotations

from abqpy.decorators import abaqus_class_doc


@abaqus_class_doc
class ModelDot:
    """The ModelDot object can be used to access an actual MeshNode, ReferencePoint, or ConstrainedSketchVertex
    object."""

    ...
